@@ -6,7 +6,7 @@ from bower.management.base import AppDirectoryCommand
 class Command(AppDirectoryCommand):
     default_apps = None
 
-    def handle_app(self, app_path):
+    def handle_app(self, app_path, **options):
         init_files = os.path.join(os.path.dirname(__file__), "../init_files")
         for init_file in os.listdir(init_files):
             target_file = os.path.join(app_path, init_file)
